#!/usr/bin/python3

from nmigen import *
from uart import *
from nmigen_boards.ice40_hx8k_b_evn import *
from nmigen.build import *

class Top(Elaboratable):

    def elaborate(self, platform):
        inpins = [ Resource("inpins", 0, Pins("B1 B2 C1 C2 D1 D2 E2 F1"), Attrs(IO_STANDARD="SB_LVCMOS")) ]
        platform.add_resources(inpins)

        m = Module()

        timer = Signal(24)

        #Connect TX to B12
        led0 = platform.request('led', 0)
        muart = platform.request('uart')
        data  = platform.request('inpins',0)
        dataA = Signal(8)
        rdy   = Signal(1)

        with m.If(timer[-1]):
            m.d.sync += [
              rdy.eq(1),
              timer.eq(0)
            ]
        with m.Else():
            m.d.sync += [
                timer.eq(timer + 1)
            ]

        with m.If(rdy == 1):
            m.d.sync += [
                rdy.eq(0)
            ]

        m.d.sync += [
            dataA.eq(data.i[0:8] + 0x60)
        ]

        m.d.comb += [
            led0.eq(timer[-1])
        ]

        # UART
        uart = UART(divisor=1250)
        uart.tx_o = muart.tx


        m.d.comb += [
            uart.tx_data.eq(dataA),
            uart.tx_rdy.eq(rdy)
        ]
        
        m.submodules += [uart] 

        return m


if __name__ == '__main__':
    platform = ICE40HX8KBEVNPlatform()

    platform.build(Top(), do_program=True)
